/***
 * GASP: a gaming services platform for mobile multiplayer games.
 * Copyright (C) 2004 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.mega.moods.generator;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.List;


import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

import org.mega.moods.generator.typesClasses.Types;


public class TypesJAXBReader {
	private String fichierXML;
    private JAXBContext jaxbc;
    private Types types;
    private Marshaller m;
	private Unmarshaller u;
    
    
    public TypesJAXBReader(String fileXML) throws FileNotFoundException{ 
    	fichierXML = fileXML;
    	
    	// create a JAXB context providing xjc compiled classes use.
    	try{ 
    		jaxbc = JAXBContext.newInstance("org.mega.moods.generator.typesClasses");
    		u = jaxbc.createUnmarshaller();
    		m = jaxbc.createMarshaller();
    		FileInputStream xml = new FileInputStream(fichierXML);
   			types = (Types)u.unmarshal( xml );
    	}
    	catch( JAXBException je ) {
            je.printStackTrace();
		}
    }
    
    
    /**
     * Returns the mode of generator execution.
     * Mode:
     * * "normal": no compacting, manage the objects of the types declared.
     * * "compact": fusionning the types in only one class.
     * 
     * @return String - the generator execution mode 
     * @throws IOException
     */
    public String getMode() throws IOException{
        return types.getMode();
    }

    /**
     * Returns in case of mode "compact", the mono class name.
     * 
     * @return String - destination class name
     * @throws IOException
     */
    public String getDestClassName() throws IOException{
        return types.getDestClassName();
    }
    
	/**
	 * Return the list of types contained by the xml file.
	 * 
	 * @return List the types list
	 */
	public List getTypes() throws IOException {			
		return types.getType();
	}
}

